@@ -32,11 +32,7 @@ from .document_understanding import (
     TableBoundHint,
     TableExtractionParams,
 )
-from .geometry import (
-    BoundingPoly,
-    NormalizedVertex,
-    Vertex,
-)
+from .geometry import BoundingPoly, NormalizedVertex, Vertex
 
 __all__ = (
     "Document",
